==> kdxfsdk-0.0.15.tar.gz: kdxfsdk-0.0.15/kdxfsdk/ali_tts.py <==
# -*- coding:utf-8 -*-
#
#   author: iflytek
#
#  本demo测试时运行的环境为：Windows + Python3.7
#  本demo测试成功运行时所安装的第三方库及其版本如下：
#   cffi==1.12.3
#   gevent==1.4.0
#   greenlet==0.4.15
#   pycparser==2.19
#   six==1.12.0
#   websocket==0.2.1
#   websocket-client==0.56.0
#
#  错误码链接：https://www.xfyun.cn/document/error-code （code返回错误码时必看）
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
import websocket
import datetime
import hashlib
import base64
import hmac
import json
from urllib.parse import urlencode
import time
import ssl
from wsgiref.handlers import format_date_time
from datetime import datetime
from time import mktime
from qcloud_cos import CosConfig
from qcloud_cos import CosS3Client
from random import choice
import requests
import _thread as thread


STATUS_FIRST_FRAME = 0  # 第一帧的标识
STATUS_CONTINUE_FRAME = 1  # 中间帧标识
STATUS_LAST_FRAME = 2  # 最后一帧的标识


class Ws_Param(object):
    # 初始化
    def __init__(self, APPID, APIKey, APISecret, Text):
        self.APPID = APPID
        self.APIKey = APIKey
        self.APISecret = APISecret
        self.Text = Text

        # 公共参数(common)
        self.CommonArgs = {"app_id": self.APPID}
        # 业务参数(business)，更多个性化参数可在官网查看
        self.BusinessArgs = {"aue": "raw", "auf": "audio/L16;rate=16000", "vcn": "xiaoyan", "tte": "utf8"}
        self.Data = {"status": 2, "text": str(base64.b64encode(self.Text.encode('utf-8')), "UTF8")}

    # 生成url
    def create_url(self):
        url = 'wss://tts-api.xfyun.cn/v2/tts'
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + "ws-api.xfyun.cn" + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + "/v2/tts " + "HTTP/1.1"
        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.APISecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.APIKey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": "ws-api.xfyun.cn"
        }
        # 拼接鉴权参数，生成url
        url = url + '?' + urlencode(v)
        return url


class Tts(object):
    def __init__(self):
        secret_id = "AKIDqTt43ryimaDbkrOgFZgYBj2EBsKdbcFf"
        secret_key = "Qef6IGAyaHqFRaaN1QVTHvOceU8ZvCE4"
        region = 'ap-hongkong'
        token = None
        scheme = 'https'
        prefix = "kdxfsdk/license/tts"
        bucket = "lmxia-1253647560"

        config = CosConfig(Region=region, SecretId=secret_id, SecretKey=secret_key, Token=token, Scheme=scheme)
        client = CosS3Client(config)
        response = client.list_objects(Bucket=bucket, Prefix=prefix)
        objs = [obj for obj in response['Contents'] if str(obj.get("Size", '0')) != '0']
        iat_item = choice(objs)
        license_key = iat_item.get("Key", "kdxfsdk/license/tts/lmxia.config")
        spec_obj = client.get_object(
            Bucket=bucket,
            Key=license_key,
        )
        fp = spec_obj['Body'].get_raw_stream().read()
        license_obj = json.loads(fp)
        self.APPID = license_obj.get("APPID")
        self.APIKey = license_obj.get("APIKey")
        self.APISecret = license_obj.get("APISecret")

    def make_speach(self, text):
        # 测试时候在此处正确填写相关信息即可运行
        # 收到websocket连接建立的处理
        wsParam = Ws_Param(self.APPID, self.APIKey, self.APISecret, text)
        websocket.enableTrace(False)
        wsUrl = wsParam.create_url()

        def on_open(ws):
            def run(*args):
                intervel = 2  # 等待结果间隔(单位:s)

                d = {"common": wsParam.CommonArgs,
                     "business": wsParam.BusinessArgs,
                     "data": wsParam.Data,
                     }
                d = json.dumps(d)
                ws.send(d)
                # sleep等待服务端返回结果
                time.sleep(intervel)
                ws.close()

            thread.start_new_thread(run, ())

        ws = websocket.WebSocketApp(wsUrl, on_message=on_message, on_error=on_error, on_close=on_close)
        ws.on_open = on_open
        ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})


# 收到websocket消息的处理
def on_message(ws, message):
    try:
        code = json.loads(message)["code"]
        sid = json.loads(message)["sid"]
        audio = json.loads(message)["data"]["audio"]
        audio = base64.b64decode(audio)
        if code != 0:
            errMsg = json.loads(message)["message"]
            print("sid:%s call error:%s code is:%s" % (sid, errMsg, code))
        else:
            with open('./speach.pcm', 'ab') as f:
                f.write(audio)
    except Exception as e:
        print("receive msg,but parse exception:", e)


# 收到websocket错误的处理
def on_error(ws, error):
    print("### error:", error)


# 收到websocket关闭的处理
def on_close(ws):
    pass


if __name__ == "__main__":
    tts = Tts()
    tts.make_speach("你好么我很好事实上是谁呢")

==> kdxfsdk-0.0.27.tar.gz: kdxfsdk-0.0.27/kdxfsdk/ali_tts.py <==
# -*- coding:utf-8 -*-
#
#   author: iflytek
#
#  本demo测试时运行的环境为：Windows + Python3.7
#  本demo测试成功运行时所安装的第三方库及其版本如下：
#   cffi==1.12.3
#   gevent==1.4.0
#   greenlet==0.4.15
#   pycparser==2.19
#   six==1.12.0
#   websocket==0.2.1
#   websocket-client==0.56.0
#
#  错误码链接：https://www.xfyun.cn/document/error-code （code返回错误码时必看）
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
import websocket
import datetime
import hashlib
import base64
import hmac
import json
from urllib.parse import urlencode
import time
import ssl
from wsgiref.handlers import format_date_time
from datetime import datetime
from time import mktime
# from qcloud_cos import CosConfig
# from qcloud_cos import CosS3Client
# from random import choice
# import requests
import _thread as thread
import os


STATUS_FIRST_FRAME = 0  # 第一帧的标识
STATUS_CONTINUE_FRAME = 1  # 中间帧标识
STATUS_LAST_FRAME = 2  # 最后一帧的标识


class Ws_Param(object):
    # 初始化
    def __init__(self, APPID, APIKey, APISecret, Text):
        self.APPID = APPID
        self.APIKey = APIKey
        self.APISecret = APISecret
        self.Text = Text

        # 公共参数(common)
        self.CommonArgs = {"app_id": self.APPID}
        # 业务参数(business)，更多个性化参数可在官网查看
        self.BusinessArgs = {"aue": "raw", "auf": "audio/L16;rate=16000", "vcn": "xiaoyan", "tte": "utf8"}
        self.Data = {"status": 2, "text": str(base64.b64encode(self.Text.encode('utf-8')), "UTF8")}

    # 生成url
    def create_url(self):
        url = 'wss://tts-api.xfyun.cn/v2/tts'
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + "ws-api.xfyun.cn" + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + "/v2/tts " + "HTTP/1.1"
        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.APISecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.APIKey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": "ws-api.xfyun.cn"
        }
        # 拼接鉴权参数，生成url
        url = url + '?' + urlencode(v)
        return url


class Tts(object):
    def __init__(self):
        # secret_id = "AKIDqTt43ryimaDbkrOgFZgYBj2EBsKdbcFf"
        # secret_key = "Qef6IGAyaHqFRaaN1QVTHvOceU8ZvCE4"
        # region = 'ap-hongkong'
        # token = None
        # scheme = 'https'
        # prefix = "kdxfsdk/license/tts"
        # bucket = "lmxia-1253647560"
        #
        # config = CosConfig(Region=region, SecretId=secret_id, SecretKey=secret_key, Token=token, Scheme=scheme)
        # client = CosS3Client(config)
        # response = client.list_objects(Bucket=bucket, Prefix=prefix)
        # objs = [obj for obj in response['Contents'] if str(obj.get("Size", '0')) != '0']
        # iat_item = choice(objs)
        # license_key = iat_item.get("Key", "kdxfsdk/license/tts/lmxia.config")
        # spec_obj = client.get_object(
        #     Bucket=bucket,
        #     Key=license_key,
        # )
        # fp = spec_obj['Body'].get_raw_stream().read()
        # license_obj = json.loads(fp)
        # self.APPID = license_obj.get("APPID")
        # self.APIKey = license_obj.get("APIKey")
        # self.APISecret = license_obj.get("APISecret")
        self.APPID = "5cc5623f"
        self.APIKey = "fd98921894fe1bade5b95f1ae75d49d8"
        self.APISecret = "8f57d4b3dbb3fb4b77098df502be780f"

    def make_speach(self, text):
        # 测试时候在此处正确填写相关信息即可运行
        # 收到websocket连接建立的处理
        try:
            os.remove("./speach.pcm")
        except OSError:
            pass
        wsParam = Ws_Param(self.APPID, self.APIKey, self.APISecret, text)
        websocket.enableTrace(False)
        wsUrl = wsParam.create_url()

        def on_open(ws):
            def run(*args):
                intervel = 2  # 等待结果间隔(单位:s)

                d = {"common": wsParam.CommonArgs,
                     "business": wsParam.BusinessArgs,
                     "data": wsParam.Data,
                     }
                d = json.dumps(d)
                ws.send(d)
                # sleep等待服务端返回结果
                time.sleep(intervel)
                ws.close()

            thread.start_new_thread(run, ())

        ws = websocket.WebSocketApp(wsUrl, on_message=on_message, on_error=on_error, on_close=on_close)
        ws.on_open = on_open
        ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})


# 收到websocket消息的处理
def on_message(ws, message):
    try:
        code = json.loads(message)["code"]
        sid = json.loads(message)["sid"]
        audio = json.loads(message)["data"]["audio"]
        audio = base64.b64decode(audio)
        if code != 0:
            errMsg = json.loads(message)["message"]
            print("sid:%s call error:%s code is:%s" % (sid, errMsg, code))
        else:
            with open('./speach.pcm', 'ab') as f:
                f.write(audio)
    except Exception as e:
        print("receive msg,but parse exception:", e)


# 收到websocket错误的处理
def on_error(ws, error):
    print("### error:", error)


# 收到websocket关闭的处理
def on_close(ws):
    pass


if __name__ == "__main__":
    tts = Tts()
    tts.make_speach("你好么我很好事实上是谁呢")
